@@ -95,7 +95,10 @@ def search(tree, data, ns, nstree, remove_empty_nodes, escape):
                 "\{%s\}" % re.escape(ns.rstrip('.')),
                 values, escape)
         # Continue replacement in deeper namespaces.
-        for k in nstree:
+        keys = nstree.keys()
+        keys.sort()
+        keys.reverse()  # make indexed ns be replaced first.
+        for k in keys:
             new_ns = '%s%s.' % (ns, k)
             new_nstree = nstree.get(k)
 
@@ -108,7 +111,7 @@ def search(tree, data, ns, nstree, remove_empty_nodes, escape):
                 subdata = values.get(k)
             except:
                 subdata = getattr(values, k, None)
-            if slice_:
+            if slice_ and subdata:
                 subdata = subdata[int(slice_[1:-1])]
 
             repl = search(repl, subdata, new_ns,
