@@ -110,13 +110,19 @@ def test_objects():
     'I like Python.'
 
 def test_index():
-    print str(Template("""
-        <georss:point>{geometry.coordinates[0]} {geometry.coordinates[1]}</georss:point>
-    """).process(
-        {"geometry": { "type": "Point", "coordinates": [45.256, -71.92] }}
-    )).strip() 
     assert str(Template("""
         <georss:point>{geometry.coordinates[0]} {geometry.coordinates[1]}</georss:point>
     """).process(
         {"geometry": { "type": "Point", "coordinates": [45.256, -71.92] }}
     )).strip() == "<georss:point>45.256 -71.92</georss:point>"
+
+    template = Template("""<feed><updated>{entries[0].updated}</updated><entry><id>{entries.id}</id><updated>{entries.updated}</updated></entry></feed>""")
+    assert str(template.process({"entries": [{"updated": "today", "id": 1}, {"updated": "yesterday", "id": 0}]})) == \
+    '<feed><updated>today</updated><entry><id>1</id><updated>today</updated></entry><entry><id>0</id><updated>yesterday</updated></entry></feed>'
+
+    template = Template("""<feed><updated>{members[0].entity.updated}</updated><entry><id>{members.id}</id><updated>{members.entity.updated}</updated></entry></feed>""")
+    assert str(template.process({"members": [{'entity': {"updated": "today"}, "id": 1}, {'entity': {"updated": "yesterday"}, "id": 0}]})) == \
+    '<feed><updated>today</updated><entry><id>1</id><updated>today</updated></entry><entry><id>0</id><updated>yesterday</updated></entry></feed>'
+    template = Template("""<feed><updated>{entries[0].entity.updated}</updated><entry><id>{entries.id}</id><updated>{entries.entity.updated}</updated></entry></feed>""")
+    assert str(template.process({"entries": [{'entity': {"updated": "today"}, "id": 1}, {'entity': {"updated": "yesterday"}, "id": 0}]})) == \
+    '<feed><updated>today</updated><entry><id>1</id><updated>today</updated></entry><entry><id>0</id><updated>yesterday</updated></entry></feed>'
